@@ -243,7 +243,7 @@ class Mocker(object):
     IMG_SQUARE_SPACE = {
         'url': "https://station-spatiale.s3.eu-west-3.amazonaws.com/cms/media-text_space.png",
         'title': "IMG_SQUARE_SPACE",
-        'name': "IMG_SQUARE_SPACE.svg",
+        'name': "IMG_SQUARE_SPACE.png",
         'model': Image
     }
 
@@ -332,6 +332,28 @@ class Mocker(object):
         'model': Image
     }
 
+    IMGS_LIGHT = [
+        IMG_SQUARE_LIGHT,
+        IMG_LOGO_LIGHT,
+        IMG_ICON_LIGHT,
+        IMG_BG_DESKTOP_LIGHT,
+        IMG_BG_MOBILE_LIGHT,
+        IMG_BLOG_COVER_LIGHT,
+        IMG_CONTENT_HEIGHT_LIGHT,
+        IMG_CONTENT_WIDTH_LIGHT
+    ]
+
+    IMGS_SPACE = [
+        IMG_SQUARE_SPACE,
+        IMG_LOGO_SPACE,
+        IMG_ICON_SPACE,
+        IMG_BG_DESKTOP_SPACE,
+        IMG_BG_MOBILE_SPACE,
+        IMG_BLOG_COVER_SPACE,
+        IMG_CONTENT_HEIGHT_SPACE,
+        IMG_CONTENT_WIDTH_SPACE
+    ]
+
     five = lorem_ipsum.words(5)
     hun = lorem_ipsum.words(100)
     animation = {
@@ -368,6 +390,7 @@ class Mocker(object):
                 <p>{text()}</p>
                 <p><a href="#">{title()}</a>. {text()}</p><p><br/></p>
                 """
+
     @staticmethod
     def button(m_type=constants.BUTTON_PRIMARY_FULL):
         return {
@@ -417,7 +440,6 @@ class Mocker(object):
         if created:
             nav.save()
 
-
         # Header
 
         header_menus = []
@@ -496,6 +518,24 @@ class Mocker(object):
                         break
         return form
 
+    @staticmethod
+    def get_gallery(theme=constants.THEME_SPACE):
+        Gallery = get_model('cms', 'Gallery')
+        gallery, created = Gallery.objects.get_or_create(
+            help_text=theme
+        )
+        if created:
+            imgs = []
+            all = Mocker.IMGS_LIGHT if theme == constants.THEME_LIGHT else Mocker.IMGS_SPACE
+            for img in all:
+                imgs.append({
+                    'type': 'image',
+                    'value': Mocker.file(img).id
+                })
+            gallery.medias = json.dumps(imgs)
+            gallery.save()
+        return gallery
+
     @staticmethod
     def get_person():
         Person = get_model('cms', 'Person')
