@@ -39,6 +39,12 @@ const Article = {
   },
 };
 
+const initAll = function initAllComponents() {
+  Article.summary();
+  Article.summaryTitles();
+};
+
 export default {
   Article,
+  initAll,
 };
