@@ -6,18 +6,34 @@ const precacheResources = [
 ];
 
 self.addEventListener('install', (event) => {
-  event.waitUntil(
+  console.log('install')
+    event.waitUntil(
     caches.open(cacheName)
       .then(cache => cache.addAll(precacheResources)),
   );
 });
 
 self.addEventListener('fetch', (event) => {
-  event.respondWith(caches.match(event.request)
+  console.log('fetch')
+
+    event.respondWith(caches.match(event.request)
     .then((cachedResponse) => {
-      if (cachedResponse) {
+        if (cachedResponse) {
         return cachedResponse;
       }
       return fetch(event.request);
     }));
 });
+
+
+self.addEventListener('activate', function(event) {
+    console.log('activate')
+
+    event.waitUntil(
+    caches.keys().then(function(keyList) {
+      return Promise.all(keyList.map(function(key) {
+        return caches.delete(key);
+      }));
+    })
+  );
+});
\ No newline at end of file
